@@ -1,22 +1,21 @@
 metadata_default = {
     "name": "DefaultOperator",
-    "version": "0.1.0",
     "dependency": {
         "docker_image": None,
         "dockerfile": None,
         "requirements_file": None
     },
-    "operator_type": "default",
     "tags": [],
     "style": {
         "node_label": "Operator",
-        "icon_class_name": "fa-solid fa-circle",
+        "node_type": "default",
         "node_style": {
             "backgroundColor": "#ebebeb"
         },
+        "useIcon": True,
+        "icon_class_name": "fa-solid fa-circle",
+        "iconStyle": {
+            "cursor": "pointer"
+        }
     },
-    "useIcon": True,
-    "iconStyle": {
-    "cursor": "pointer"
-    }
 }
\ No newline at end of file
